%define ALD_Ver		1.2.4

#USE gcc-4.9.4

%define OrgName bzip2
Name:         uC-%{OrgName}

License:      (C) 1996-2007 Julian R Seward
Summary:      data compression library - utilities
Group:        System Environment/Libraries
Version:      1.0.6
Release:      1025.0

Source: %{OrgName}-%{version}.tar.xz
Source1: CROSS-uC.sh
Patch0: %{OrgName}-%{version}.patch

%define DestDir		/Embedded/uC-%{uC_Version}
%define uC_Version 1.0.25

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
# -----------------------------------------------------

%define _prefix /usr/uC/%{uC_Version}/static
%define _lib lib

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/usr/uC/%{uC_Version}/static/bin
%define target_  %{target}-

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{OrgName}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir %{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc
%define target_  %{nil}

%endif # !_CROSS

%define _defaultdocdir %{_datadir}/doc
%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
This package contains the bzip2 uClibc Libraries.
# -------------------
%package bin
Summary:      %{OrgName} utilities static uClibc
Group:        System Environment/Base
%description bin
%{OrgName} utilities static uClibc
#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
%patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%Build
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP

GCC_VER_STR=`%{target_}gcc -dumpversion`

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif

#CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector -std=gnu99"
CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -fno-stack-protector -std=gnu99"
LDFLAGS="-Wl,--gc-sections"

export CFLAGS

make PREFIX=%{_prefix} LDFLAGS=$LDFLAGS CC=%{target}-gcc \
	AR=%{target}-ar RANLIB=%{target}-ranlib \
	libbz2.a bzip2 bzip2recover \
	&>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP target

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make PREFIX=$RPM_BUILD_ROOT/%{_prefix} install &>FInstall_log.txt
cp CHANGES LICENSE README $RPM_BUILD_ROOT%{docdir}/

pushd $RPM_BUILD_ROOT%{_bindir}
  rm bunzip2 bzcat bzcmp bzegrep bzfgrep bzless
  ln -s bzip2 bunzip2
  ln -s bzip2 bzcat

  ln -s bzdiff bzcmp
  ln -s bzgrep bzegrep
  ln -s bzgrep bzfgrep
  ln -s bzmore bzless
popd

%if %{_CROSS} && %{BUILD_LOCAL_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME
%SOURCE1
rm -r $RPM_BUILD_ROOT%{cross_bindir}
rm -r $RPM_BUILD_ROOT%{cross_mandir}
%endif

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-bin-$SE $DD/%{name}-bin-$DE
%if %{BUILD_LOCAL_CROSS}
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif #BUILD_LOCAL_CROSS
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%Files
%{docdir}
%{_includedir}
%{_libdir}/*.a

%files bin
%{_bindir}
%{_mandir}

%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{cross_includedir}
%{cross_libdir}
%{cross_docdir}

%endif  #BUILD_LOCAL_CROSS
